module.exports = defineTest({
	description: 'handles superfluous semicolons'
});
